==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/ImageChangeCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageChangeCauseFluentImpl<A extends ImageChangeCauseFluent<A>> extends BaseFluent<A> implements ImageChangeCauseFluent<A>{
  public ImageChangeCauseFluentImpl() {
  }
  public ImageChangeCauseFluentImpl(ImageChangeCause instance) {
    this.withFromRef(instance.getFromRef()); 
    this.withImageID(instance.getImageID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ObjectReferenceBuilder fromRef;
  private String imageID;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFromRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getFromRef() {
    return this.fromRef!=null ?this.fromRef.build():null;
  }
  public ObjectReference buildFromRef() {
    return this.fromRef!=null ?this.fromRef.build():null;
  }
  public A withFromRef(ObjectReference fromRef) {
    _visitables.get("fromRef").remove(this.fromRef);
    if (fromRef!=null){ this.fromRef= new ObjectReferenceBuilder(fromRef); _visitables.get("fromRef").add(this.fromRef);} else { this.fromRef = null; _visitables.get("fromRef").remove(this.fromRef); } return (A) this;
  }
  public Boolean hasFromRef() {
    return this.fromRef != null;
  }
  public ImageChangeCauseFluent.FromRefNested<A> withNewFromRef() {
    return new ImageChangeCauseFluentImpl.FromRefNestedImpl();
  }
  public ImageChangeCauseFluent.FromRefNested<A> withNewFromRefLike(ObjectReference item) {
    return new ImageChangeCauseFluentImpl.FromRefNestedImpl(item);
  }
  public ImageChangeCauseFluent.FromRefNested<A> editFromRef() {
    return withNewFromRefLike(getFromRef());
  }
  public ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRef() {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): new ObjectReferenceBuilder().build());
  }
  public ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRefLike(ObjectReference item) {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): item);
  }
  public String getImageID() {
    return this.imageID;
  }
  public A withImageID(String imageID) {
    this.imageID=imageID; return (A) this;
  }
  public Boolean hasImageID() {
    return this.imageID != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageChangeCauseFluentImpl that = (ImageChangeCauseFluentImpl) o;
    if (fromRef != null ? !fromRef.equals(that.fromRef) :that.fromRef != null) return false;
    if (imageID != null ? !imageID.equals(that.imageID) :that.imageID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fromRef,  imageID,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fromRef != null) { sb.append("fromRef:"); sb.append(fromRef + ","); }
    if (imageID != null) { sb.append("imageID:"); sb.append(imageID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FromRefNestedImpl<N> extends ObjectReferenceFluentImpl<ImageChangeCauseFluent.FromRefNested<N>> implements ImageChangeCauseFluent.FromRefNested<N>,Nested<N>{
    FromRefNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    FromRefNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeCauseFluentImpl.this.withFromRef(builder.build());
    }
    public N endFromRef() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/ImageChangeCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageChangeCauseFluentImpl<A extends ImageChangeCauseFluent<A>> extends BaseFluent<A> implements ImageChangeCauseFluent<A>{
  public ImageChangeCauseFluentImpl() {
  }
  public ImageChangeCauseFluentImpl(ImageChangeCause instance) {
    if (instance != null) {
      this.withFromRef(instance.getFromRef());
      this.withImageID(instance.getImageID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ObjectReferenceBuilder fromRef;
  private String imageID;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFromRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getFromRef() {
    return this.fromRef!=null ?this.fromRef.build():null;
  }
  public ObjectReference buildFromRef() {
    return this.fromRef!=null ?this.fromRef.build():null;
  }
  public A withFromRef(ObjectReference fromRef) {
    _visitables.get("fromRef").remove(this.fromRef);
    if (fromRef!=null){ this.fromRef= new ObjectReferenceBuilder(fromRef); _visitables.get("fromRef").add(this.fromRef);} else { this.fromRef = null; _visitables.get("fromRef").remove(this.fromRef); } return (A) this;
  }
  public Boolean hasFromRef() {
    return this.fromRef != null;
  }
  public ImageChangeCauseFluentImpl.FromRefNested<A> withNewFromRef() {
    return new ImageChangeCauseFluentImpl.FromRefNestedImpl();
  }
  public ImageChangeCauseFluentImpl.FromRefNested<A> withNewFromRefLike(ObjectReference item) {
    return new ImageChangeCauseFluentImpl.FromRefNestedImpl(item);
  }
  public ImageChangeCauseFluentImpl.FromRefNested<A> editFromRef() {
    return withNewFromRefLike(getFromRef());
  }
  public ImageChangeCauseFluentImpl.FromRefNested<A> editOrNewFromRef() {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): new ObjectReferenceBuilder().build());
  }
  public ImageChangeCauseFluentImpl.FromRefNested<A> editOrNewFromRefLike(ObjectReference item) {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): item);
  }
  public String getImageID() {
    return this.imageID;
  }
  public A withImageID(String imageID) {
    this.imageID=imageID; return (A) this;
  }
  public Boolean hasImageID() {
    return this.imageID != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageChangeCauseFluentImpl that = (ImageChangeCauseFluentImpl) o;
    if (!java.util.Objects.equals(fromRef, that.fromRef)) return false;

    if (!java.util.Objects.equals(imageID, that.imageID)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fromRef,  imageID,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fromRef != null) { sb.append("fromRef:"); sb.append(fromRef + ","); }
    if (imageID != null) { sb.append("imageID:"); sb.append(imageID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FromRefNestedImpl<N> extends ObjectReferenceFluentImpl<ImageChangeCauseFluentImpl.FromRefNested<N>> implements ImageChangeCauseFluentImpl.FromRefNested<N>,Nested<N>{
    FromRefNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    FromRefNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeCauseFluentImpl.this.withFromRef(builder.build());
    }
    public N endFromRef() {
      return and();
    }
    
  }
  
}
